Allow MPLS routes on IPIP and SIT devices now that they
support forwarding MPLS packets.

Signed-off-by: Simon Horman <simon.hor...@netronome.com>
Reviewed-by: Dinan Gunawardena <dinan.gunaward...@netronome.com>
---
 net/mpls/af_mpls.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/net/mpls/af_mpls.c b/net/mpls/af_mpls.c
index e9beaa58573c..5c161e7759b5 100644
--- a/net/mpls/af_mpls.c
+++ b/net/mpls/af_mpls.c
@@ -1009,10 +1009,12 @@ static int mpls_dev_notify(struct notifier_block *this, 
unsigned long event,
        unsigned int flags;
 
        if (event == NETDEV_REGISTER) {
                /* For now just support Ethernet and IPGRE devices */
                if (dev->type == ARPHRD_ETHER ||
                    dev->type == ARPHRD_LOOPBACK ||
-                   dev->type == ARPHRD_IPGRE) {
+                   dev->type == ARPHRD_IPGRE ||
+                   dev->type == ARPHRD_SIT ||
+                   dev->type == ARPHRD_TUNNEL) {
                        mdev = mpls_add_dev(dev);
                        if (IS_ERR(mdev))
                                return notifier_from_errno(PTR_ERR(mdev));
@@ -1009,10 +1009,12 @@ static int mpls_dev_notify(struct notifier_block *this, 
 
        if (event == NETDEV_REGISTER) {
-               /* For now just support Ethernet and IPGRE devices */
+               /* For now just support Ethernet, IPGRE, SIT and IPIP devices */
                if (dev->type == ARPHRD_ETHER ||
                    dev->type == ARPHRD_LOOPBACK ||
-- 
2.7.0.rc3.207.g0ac5344

Reply via email to